worker_processes        auto;
error_log               /dev/stderr info;
pid                     /tmp/nginx.pid;
daemon                  off;
events {
  worker_connections    1024;
}
http {
  proxy_temp_path       /tmp/proxy_temp;
  client_body_temp_path /tmp/client_temp;
  fastcgi_temp_path     /tmp/fastcgi_temp;
  uwsgi_temp_path       /tmp/uwsgi_temp;
  scgi_temp_path        /tmp/scgi_temp;
  include               /etc/nginx/mime.types;
  default_type          application/octet-stream;
  log_format            main  '$remote_addr - $remote_user [$time_local] "$request" '
                              '$status $body_bytes_sent "$http_referer" '
                              '"$http_user_agent" "$http_x_forwarded_for"';
  access_log            /dev/stdout main;
  sendfile              on;
  keepalive_timeout     65;

  upstream docservice {
    server unix:/tmp/oods.sock max_fails=0 fail_timeout=0s;
  }
  
  map $http_host $this_host {
      "" $host;
      default $http_host;
  }
  
  map $http_x_forwarded_proto $the_scheme {
       default $http_x_forwarded_proto;
       "" $scheme;
  }
  
  map $http_x_forwarded_host $the_host {
      default $http_x_forwarded_host;
      "" $this_host;
  }
  
  map $http_upgrade $proxy_connection {
    default upgrade;
    "" close;
  }
  
  map $http_x_forwarded_prefix $the_prefix {
    default $http_x_forwarded_prefix;
  }

  proxy_set_header Upgrade $http_upgrade;
  proxy_set_header Connection $proxy_connection;
  proxy_set_header X-Forwarded-Host $the_host;
  proxy_set_header X-Forwarded-Proto $the_scheme;
  proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;  

  #proxy_socket_keepalive on;

  client_max_body_size 100m;

  set_real_ip_from 127.0.0.1;
  real_ip_header X-Forwarded-For;
  real_ip_recursive on;
  
  server {
    listen 127.0.0.1:8084 default_server;
    server_tokens off;

    set $secure_link_secret [[ .oo.ds.env.OO_STORAGE_SECRET ]];
    include /etc/nginx/includes/ds-docservice.conf;
    include /etc/nginx/includes/ds-mime.types.conf;
  }
}
